==> mesos-1.3.3.tar.gz: mesos-1.3.3/src/tests/http_server_test_helper.hpp <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#ifndef __HTTP_SERVER_TEST_HELPER_HPP__
#define __HTTP_SERVER_TEST_HELPER_HPP__

#include <cstdint>
#include <string>

#include <stout/flags.hpp>
#include <stout/subcommand.hpp>

namespace mesos {
namespace internal {
namespace tests {

class HttpServerTestHelper : public Subcommand
{
public:
  static const char NAME[];

  struct Flags : public virtual flags::FlagsBase
  {
    Flags();

    std::string ip;
    uint16_t port;
  };

  HttpServerTestHelper() : Subcommand(NAME) {}

  Flags flags;

protected:
  virtual int execute();
  virtual flags::FlagsBase* getFlags() { return &flags; }
};

} // namespace tests {
} // namespace internal {
} // namespace mesos {

#endif // __HTTP_SERVER_TEST_HELPER_HPP__

==> mesos-1.7.1.tar.gz: mesos-1.7.1/src/tests/http_server_test_helper.hpp <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#ifndef __HTTP_SERVER_TEST_HELPER_HPP__
#define __HTTP_SERVER_TEST_HELPER_HPP__

#include <cstdint>
#include <string>

#include <stout/flags.hpp>
#include <stout/subcommand.hpp>

namespace mesos {
namespace internal {
namespace tests {

class HttpServerTestHelper : public Subcommand
{
public:
  static const char NAME[];

  struct Flags : public virtual flags::FlagsBase
  {
    Flags();

    std::string ip;
    uint16_t port;
  };

  HttpServerTestHelper() : Subcommand(NAME) {}

  Flags flags;

protected:
  int execute() override;
  flags::FlagsBase* getFlags() override { return &flags; }
};

} // namespace tests {
} // namespace internal {
} // namespace mesos {

#endif // __HTTP_SERVER_TEST_HELPER_HPP__
